@@ -1,11 +1,14 @@
 package Tree::From::FS;
 
-our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-05-06'; # DATE
-our $DIST = 'Tree-From-FS'; # DIST
-our $VERSION = '0.000.1'; # VERSION
-
+use strict;
+use warnings;
 use Exporter qw(import);
+
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2021-10-07'; # DATE
+our $DIST = 'Tree-From-FS'; # DIST
+our $VERSION = '0.000.2'; # VERSION
+
 our @EXPORT_OK = qw(create_tree_from_dir);
 
 sub create_tree_from_dir {
@@ -27,7 +30,7 @@ Tree::From::FS - Create a tree object from directory structure on the filesystem
 
 =head1 VERSION
 
-This document describes version 0.000.1 of Tree::From::FS (from Perl distribution Tree-From-FS), released on 2021-05-06.
+This document describes version 0.000.2 of Tree::From::FS (from Perl distribution Tree-From-FS), released on 2021-10-07.
 
 =head1 SYNOPSIS
 
@@ -52,19 +55,11 @@ Please visit the project's homepage at L<https://metacpan.org/release/Tree-From-
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Tree-From-FS>.
-
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-Tree-From-FS/issues>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
+Source repository is at L<https://github.com/perlancar/perl-Tree-FromFS>.
 
 =head1 SEE ALSO
 
-L<Role::TinyCommons::Tree>
+L<RoleBundle::TinyCommons::Tree>
 
 Other ways to create tree: L<Tree::From::Struct>, L<Tree::From::ObjArray>,
 L<Tree::From::Text>, L<Tree::From::TextLines>, L<Tree::Create::Callback>,
@@ -74,11 +69,36 @@ L<Tree::Create::Size>.
 
 perlancar <perlancar@cpan.org>
 
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
+beyond that are considered a bug and can be reported to me.
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2020, 2016 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Tree-From-FS>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =cut
